@@ -24,7 +24,6 @@ from __future__ import absolute_import
 import os
 from typing import Dict
 
-from ansible_compat.ports import cache
 from molecule import logger
 from molecule.api import Driver
 from molecule.util import sysexit_with_message
@@ -146,7 +145,7 @@ class Docker(Driver):
 
         platforms:
         - name: instance
-          image: centos:8
+          image: quay.io/centos/centos:stream8
           privileged: true
           volumes:
             - "/sys/fs/cgroup:/sys/fs/cgroup:rw"
@@ -183,6 +182,8 @@ class Docker(Driver):
     .. _`CMD`: https://docs.docker.com/engine/reference/builder/#cmd
     """  # noqa
 
+    _passed_sanity = False
+
     def __init__(self, config=None):
         """Construct Docker."""
         super(Docker, self).__init__(config)
@@ -221,14 +222,15 @@ class Docker(Driver):
     def ansible_connection_options(self, instance_name):
         x = {"ansible_connection": "community.docker.docker"}
         if "DOCKER_HOST" in os.environ:
-            x["ansible_docker_extra_args"] = "-H={}".format(os.environ["DOCKER_HOST"])
+            x["ansible_docker_extra_args"] = f"-H={os.environ['DOCKER_HOST']}"
         return x
 
-    @cache
     def sanity_checks(self):
         """Implement Docker driver sanity checks."""
-        log.info("Sanity checks: '{}'".format(self._name))
+        if self._passed_sanity:
+            return
 
+        log.info("Sanity checks: '%s'", self._name)
         try:
             import docker
             import requests
@@ -243,21 +245,24 @@ class Docker(Driver):
             )
             sysexit_with_message(msg)
 
+        self._passed_sanity = True
+
     def reset(self):
         import docker
 
         client = docker.from_env()
         for c in client.containers.list(filters={"label": "owner=molecule"}):
-            log.info("Stopping docker container %s ..." % c.id)
+            log.info("Stopping docker container %s ...", c.id)
             c.stop(timeout=3)
         result = client.containers.prune(filters={"label": "owner=molecule"})
         for c in result.get("ContainersDeleted") or []:
-            log.info("Deleted container %s" % c)
+            log.info("Deleted container %s", c)
         for n in client.networks.list(filters={"label": "owner=molecule"}):
-            log.info("Removing docker network %s ...." % n.name)
+            log.info("Removing docker network %s ...", n.name)
             n.remove()
 
     @property
     def required_collections(self) -> Dict[str, str]:
         """Return collections dict containing names and versions required."""
-        return {"community.docker": "1.8.0"}
+        # https://galaxy.ansible.com/community/docker
+        return {"community.docker": "3.0.0-a2"}
